@@ -1,7 +1,9 @@
 package App::Fasops;
 
-our $VERSION = '0.3.10';
+our $VERSION = '0.3.13';
 
+use strict;
+use warnings;
 use App::Cmd::Setup -app;
 
 1;
