@@ -12,7 +12,13 @@ use constant abstract => 'realign alignments';
 sub opt_spec {
     return (
         [ "outfile|o=s", "Output filename. [stdout] for screen." ],
-        [ "msa=s", "Aligning program. Default is [clustalw].", { default => "clustalw" } ],
+        [ "outgroup",    "Has outgroup at the end of blocks.", ],
+        [ "msa=s", "Aligning program. Default is [clustalw].", { default => "mafft" } ],
+        [   "quick",
+            "Quick mode, only aligning indel adjacent regions. Suitable for multiz outputs.",
+        ],
+        [ "pad=i",  "In quick mode, enlarge indel regions", { default => 50 } ],
+        [ "fill=i", "In quick mode, join indel regions",    { default => 50 } ],
     );
 }
 
@@ -27,9 +33,9 @@ sub description {
     my $desc;
     $desc .= ucfirst(abstract) . ".\n";
     $desc .= "List of msa:\n";
-    $desc .= " " x 4 . "clustalw\n";
-    $desc .= " " x 4 . "muscle\n";
     $desc .= " " x 4 . "mafft\n";
+    $desc .= " " x 4 . "muscle\n";
+    $desc .= " " x 4 . "clustalw\n";
     $desc .= " " x 4 . "none:    means skip realigning\n";
 
     return $desc;
@@ -70,25 +76,38 @@ sub execute {
             my $info_of = App::Fasops::Common::parse_block($content);
             $content = '';
 
+            my @keys     = keys %{$info_of};
+            my $seq_refs = [];
+            for my $key (@keys) {
+                push @{$seq_refs}, $info_of->{$key}{seq};
+            }
+
+            #----------------------------#
+            # realigning
+            #----------------------------#
             if ( $opt->{msa} ne "none" ) {
-                my @keys = keys %{$info_of};
-
-                my @seqs;
-                for my $key (@keys) {
-                    push @seqs, $info_of->{$key}{seq};
+                if ( $opt->{quick} ) {
+                    $seq_refs
+                        = App::Fasops::Common::align_seqs_quick( $seq_refs, $opt->{msa},
+                        $opt->{pad}, $opt->{fill} );
                 }
-                my $refined = App::Fasops::Common::align_seqs( \@seqs, $opt->{msa} );
-
-                for my $i ( 0 .. $#keys ) {
-                    printf {$out_fh} ">%s\n", App::RL::Common::encode_header( $info_of->{ $keys[$i] } );
-                    printf {$out_fh} "%s\n",  uc $refined->[$i];
+                else {
+                    $seq_refs = App::Fasops::Common::align_seqs( $seq_refs, $opt->{msa} );
                 }
             }
-            else {
-                for my $key ( keys %{$info_of} ) {
-                    printf {$out_fh} ">%s\n", App::RL::Common::encode_header( $info_of->{ $key } );
-                    printf {$out_fh} "%s\n",  $info_of->{$key}{seq};
-                }
+
+            #----------------------------#
+            # trimming
+            #----------------------------#
+            App::Fasops::Common::trim_pure_dash($seq_refs);
+            if ( $opt->{outgroup} ) {
+                App::Fasops::Common::trim_outgroup($seq_refs);
+                App::Fasops::Common::trim_complex_indel($seq_refs);
+            }
+
+            for my $i ( 0 .. $#keys ) {
+                printf {$out_fh} ">%s\n", App::RL::Common::encode_header( $info_of->{ $keys[$i] } );
+                printf {$out_fh} "%s\n",  uc $seq_refs->[$i];
             }
 
             print {$out_fh} "\n";
